==> biz-erp-2.2.0-20160913.123106-28-sources.jar: com/baijia/tianxiao/biz/erp/service/ErpCourseListService.java <==
/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 */

package com.baijia.tianxiao.biz.erp.service;

import com.baijia.tianxiao.biz.erp.dto.response.CourseListInfoDto;
import com.baijia.tianxiao.biz.erp.dto.response.studentCenter.WeiKeListInfoDto;
import com.baijia.tianxiao.sal.course.dto.request.CourseListRequestDto;
import com.baijia.tianxiao.sal.course.dto.request.WeikeRequestDto;
import com.baijia.tianxiao.sqlbuilder.dto.PageDto;

import java.util.Date;
import java.util.List;

/**
 * @title ErpCourseListService
 * @desc TODO
 * @author shanyu
 * @date 2015年12月25日
 * @version 1.0
 */

public interface ErpCourseListService {

    /**
     * 
     * @param orgId 获取机构班级列表（设班模块）
     * @param startTime
     * @param endTime
     * @param searchKey
     * @param pageDto
     * @return
     */
    public List<CourseListInfoDto> getCourseList(Long orgId, Date startTime, Date endTime,CourseListRequestDto params, PageDto pageDto);

    /**
     * 查看课节详情
     * 
     * @param orgId
     * @param courseId
     * @return
     */
    public CourseListInfoDto getCourseDetail(Long orgId, Long orgCourseId);

    /**
     * 带有到课率统计信息的课程列表
     * 
     * @param orgId
     * @param searchKey
     * @param pageDto
     * @return
     */
    List<CourseListInfoDto> getCourseListWithAttendanceRate(Long orgId, String searchKey, PageDto pageDto);

    /**
     * 设班微课列表
     * @author shizuwei
     * @param orgId
     * @param requestDto
     * @return
     */
    List<WeiKeListInfoDto> getWeikeList(Long orgId, WeikeRequestDto requestDto);
}

==> biz-erp-2.26.1-20170608.021305-4-sources.jar: com/baijia/tianxiao/biz/erp/service/ErpCourseListService.java <==
/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 */

package com.baijia.tianxiao.biz.erp.service;

import com.baijia.tianxiao.biz.erp.dto.response.AppCourseListInfoDto;
import com.baijia.tianxiao.biz.erp.dto.response.CourseListInfoDto;
import com.baijia.tianxiao.biz.erp.dto.response.studentCenter.WeiKeListInfoDto;
import com.baijia.tianxiao.sal.course.dto.request.CourseListRequestDto;
import com.baijia.tianxiao.sal.course.dto.request.WeikeRequestDto;
import com.baijia.tianxiao.sqlbuilder.dto.PageDto;

import java.util.Date;
import java.util.List;

/**
 * @title ErpCourseListService
 * @desc TODO
 * @author shanyu
 * @date 2015年12月25日
 * @version 1.0
 */

public interface ErpCourseListService {

    /**
     * 存课程列表,去掉其他不需要的查询,提高效率
     * @param orgId
     * @param startTime
     * @param endTime
     * @param params
     * @param pageDto
     * @return
     */
    public List<AppCourseListInfoDto> getOnlyCourseList(Long orgId, Date startTime, Date endTime, CourseListRequestDto params, PageDto pageDto);
    /**
     * 
     * @param orgId 获取机构班级列表（设班模块）
     * @param startTime
     * @param endTime
     * @param pageDto
     * @param clazz 表头header的对应dto,CourseListInfoDto或者ClassListInfoDtoForVip
     * @return
     */
    public <E> List<E> getCourseList(Long orgId, Date startTime, Date endTime,CourseListRequestDto params, PageDto pageDto,Class<E> clazz);

    /**
     * 查看课节详情
     * 
     * @param orgId
     * @param courseId
     * @return
     */
    public CourseListInfoDto getCourseDetail(Long orgId, Long orgCourseId);

    /**
     * 带有到课率统计信息的课程列表
     * 
     * @param orgId
     * @param searchKey
     * @param pageDto
     * @return
     */
    List<CourseListInfoDto> getCourseListWithAttendanceRate(Long orgId, String searchKey, PageDto pageDto);

    /**
     * 设班微课列表
     * @author shizuwei
     * @param orgId
     * @param requestDto
     * @return
     */
    List<WeiKeListInfoDto> getWeikeList(Long orgId, WeikeRequestDto requestDto);

}
